Learn R Programming

ggghost (version 0.2.3)

reanimate: Bring a ggplot to life (re-animate)

Description

Creates an animation showing the stepwise process of building up a ggplot. Successively adds calls from a ggghost object and then combines these into an animated GIF.

Usage

reanimate(
  object,
  gifname = "ggghost.gif",
  interval = 1,
  ani.width = 600,
  ani.height = 600
)

lazarus( object, gifname = "ggghost.gif", interval = 1, ani.width = 600, ani.height = 600 )

Value

TRUE if it gets that far

Arguments

object

A ggghost object to animate

gifname

Output filename to save the .gif to (not including any path, will be saved to current directory)

interval

A positive number to set the time interval of the animation (unit in seconds); see animation::ani.options

ani.width

width of image frames (unit in px); see animation::ani.options

ani.height

height of image frames (unit in px); see animation::ani.options

Examples

Run this code
if (FALSE) {
## create an animation showing the process of building up a plot
reanimate(z, "mycoolplot.gif")
}

Run the code above in your browser using DataLab