powered by
Creates an animation showing the stepwise process of building up a ggplot. Successively adds calls from a ggghost object and then combines these into an animated GIF.
reanimate( object, gifname = "ggghost.gif", interval = 1, ani.width = 600, ani.height = 600 )lazarus( object, gifname = "ggghost.gif", interval = 1, ani.width = 600, ani.height = 600 )
lazarus( object, gifname = "ggghost.gif", interval = 1, ani.width = 600, ani.height = 600 )
TRUE if it gets that far
TRUE
A ggghost object to animate
Output filename to save the .gif to (not including any path, will be saved to current directory)
A positive number to set the time interval of the animation (unit in seconds); see animation::ani.options
animation::ani.options
width of image frames (unit in px); see animation::ani.options
height of image frames (unit in px); see animation::ani.options
if (FALSE) { ## create an animation showing the process of building up a plot reanimate(z, "mycoolplot.gif") }
Run the code above in your browser using DataLab